@@ -26,7 +26,7 @@ from PIL import Image, ImageFont
 from PIL import ImageDraw
 import logging
 
-from cw_base import ContourWriterBase
+from pycoast.cw_base import ContourWriterBase
 
 logger = logging.getLogger(__name__)
 
@@ -50,7 +50,7 @@ class ContourWriter(ContourWriterBase):
 
         return ImageDraw.Draw(image)
 
-    def _engine_text_draw(self, draw, (x_pos, y_pos), txt, font, **kwargs):
+    def _engine_text_draw(self, draw, x_pos, y_pos, txt, font, **kwargs):
         draw.text((x_pos, y_pos), txt, font=font, fill=kwargs['fill'])
 
     def _draw_polygon(self, draw, coordinates, **kwargs):
@@ -218,7 +218,7 @@ class ContourWriter(ContourWriterBase):
         self._add_polygon(image, area_def, lonlats, x_offset=x_offset,
                           y_offset=y_offset, fill=fill, outline=outline)
 
-    def add_grid(self, image, area_def, (Dlon, Dlat), (dlon, dlat),
+    def add_grid(self, image, area_def, Dlonlat, dlonlat,
                  font=None, write_text=True, fill=None, outline='white',
                  minor_outline='white', minor_is_tick=True,
                  lon_placement='tb', lat_placement='lr'):
@@ -229,9 +229,9 @@ class ContourWriter(ContourWriterBase):
             PIL image object
         proj4_string : str
             Projection of area as Proj.4 string
-        (Dlon,Dlat): (float,float)
+        Dlonlat: (float, float)
             Major grid line separation
-        (dlon,dlat): (float,float)
+        dlonlat: (float, float)
             Minor grid line separation
         font: PIL ImageFont object, optional
             Font for major line markings
@@ -246,12 +246,14 @@ class ContourWriter(ContourWriterBase):
         minor_is_tick : boolean, optional
             Use tick minor line style (True) or full minor line style (False)
         """
+        Dlon, Dlat = Dlonlat
+        dlon, dlat = dlonlat
         self._add_grid(image, area_def, Dlon, Dlat, dlon, dlat, font=font,
                        write_text=write_text, fill=fill, outline=outline,
                        minor_outline=minor_outline, minor_is_tick=minor_is_tick,
                        lon_placement=lon_placement, lat_placement=lat_placement)
 
-    def add_grid_to_file(self, filename, area_def, (Dlon, Dlat), (dlon, dlat),
+    def add_grid_to_file(self, filename, area_def, Dlonlat, dlonlat,
                          font=None, write_text=True, fill=None, outline='white',
                          minor_outline='white', minor_is_tick=True,
                          lon_placement='tb', lat_placement='lr'):
@@ -262,9 +264,9 @@ class ContourWriter(ContourWriterBase):
             PIL image object
         proj4_string : str
             Projection of area as Proj.4 string
-        (Dlon,Dlat): (float,float)
+        Dlonlat: (float, float)
             Major grid line separation
-        (dlon,dlat): (float,float)
+        dlonlat: (float, float)
             Minor grid line separation
         font: PIL ImageFont object, optional
             Font for major line markings
@@ -279,9 +281,8 @@ class ContourWriter(ContourWriterBase):
         minor_is_tick : boolean, optional
             Use tick minor line style (True) or full minor line style (False)
         """
-
         image = Image.open(filename)
-        self.add_grid(image, area_def, (Dlon, Dlat), (dlon, dlat), font=font,
+        self.add_grid(image, area_def, Dlonlat, dlonlat, font=font,
                       write_text=write_text, fill=fill, outline=outline,
                       minor_outline=minor_outline,
                       minor_is_tick=minor_is_tick,
